/*
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2009 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Kirill Maximov <kir@rus.net>                                 |
   +----------------------------------------------------------------------+
*/

/* $Id: cyr_convert.h,v 1.11.2.1.2.1.2.2 2008/12/31 11:15:44 sebastian Exp $ */

#ifndef CYR_CONVERT_H
#define CYR_CONVERT_H

PHP_FUNCTION(convert_cyr_string);

#endif /* CYR_CONVERT_H */



